==> security-engine-starter-1.0-sources.jar: digital/nedra/commons/starter/security/engine/core/RoleBuilder.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.function.BiPredicate;
import lombok.NoArgsConstructor;
import lombok.ToString;

public interface RoleBuilder {

  RoleBuilder role(String role);

  ContextConfigure authority(String authority);

  RoleBuilder and();

  RoleBuilder handler(BiPredicate<String, Object> func);

  RoleHandler build();

  @NoArgsConstructor
  @ToString
  class DefaultRoleBuilder implements RoleBuilder {
    private String role;
    private List<Authority> authorities;
    private BiPredicate<String, Object> handler;

    public RoleHandler.DefaultRoleHandler build() {
      Objects.requireNonNull(this.role, "Role is not set");
      Objects.requireNonNull(this.authorities, "Authorities are not set");
      return new RoleHandler.DefaultRoleHandler(this.role, this.authorities, this.handler);
    }

    public RoleBuilder role(final String role) {
      this.role = role;
      return this;
    }

    AuthorityConfigurer.DefaultAuthorityConfigurer conf;

    @Override
    public ContextConfigure authority(final String authority) {
      this.conf = new AuthorityConfigurer.DefaultAuthorityConfigurer();
      conf.setName(authority);
      conf.setParent(this);
      return conf.context();
    }

    @Override
    public RoleBuilder and() {
      if (this.authorities == null) {
        this.authorities = new ArrayList<>();
      }
      if (this.conf != null) {
        this.authorities.add(
            Authority.builder()
                .name(this.conf.getName())
                .available(this.conf.isAvailable())
                .context(this.conf.getFields())
                .build()
        );
      }
      return this;
    }

    @Override
    public RoleBuilder handler(final BiPredicate<String, Object> func) {
      this.handler = func;
      return this;
    }

  }
}

==> security-engine-starter-1.1.1-sources.jar: digital/nedra/commons/starter/security/engine/core/RoleBuilder.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.security.engine.core;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.function.BiPredicate;
import lombok.NoArgsConstructor;
import lombok.ToString;

public interface RoleBuilder {

  RoleBuilder role(String role);

  ContextConfigure authority(String authority);

  RoleBuilder and();

  RoleBuilder handler(BiPredicate<String, Object> func);

  RoleHandler build();

  @NoArgsConstructor
  @ToString
  class DefaultRoleBuilder implements RoleBuilder {
    private String role;
    private List<Authority> authorities = new ArrayList<>();
    private BiPredicate<String, Object> handler;

    AuthorityConfigurer.DefaultAuthorityConfigurer conf;

    public RoleHandler.DefaultRoleHandler build() {
      Objects.requireNonNull(this.role, "Role is not set");
      Objects.requireNonNull(this.authorities, "Authorities are not set");
      return new RoleHandler.DefaultRoleHandler(this.role, this.authorities, this.handler);
    }

    public RoleBuilder role(final String role) {
      this.role = role;
      return this;
    }

    @Override
    public ContextConfigure authority(final String authority) {
      this.conf = new AuthorityConfigurer.DefaultAuthorityConfigurer();
      conf.setName(authority);
      conf.setParent(this);
      return conf.context();
    }

    @Override
    public RoleBuilder and() {
      if (this.conf != null) {
        this.authorities.add(
            Authority.builder()
                .name(this.conf.getName())
                .available(this.conf.isAvailable())
                .context(this.conf.getFields())
                .build()
        );
      }
      return this;
    }

    @Override
    public RoleBuilder handler(final BiPredicate<String, Object> func) {
      this.handler = func;
      return this;
    }

  }
}
